/**
 * PETALS - PETALS Services Platform. Copyright (c) 2007 EBM Websourcing,
 * http://www.ebmwebsourcing.com/
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version. This library is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * -------------------------------------------------------------------------
 * $Id:
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.bc.ftp;

import java.util.List;

import javax.jbi.JBIException;
import javax.jbi.messaging.Fault;

import org.ow2.petals.component.framework.api.exception.PEtALSCDKException;
import org.ow2.petals.component.framework.api.message.Exchange;
import org.ow2.petals.component.framework.util.UtilFactory;

/**
 * 
 * @author alouis
 * 
 */
public class FTPUtil {
    /**
     * generates the XML representation of the file name list
     * 
     * @param names
     * @return
     */
    public static String generateFileNameList(List<String> names, String operation) {
        StringBuffer result = new StringBuffer();
        result.append("<tns:" + operation + "Response xmlns:tns='");
        result.append(FTPConstants.FTP_SERVICE_NS);
        result.append("'>");
        for (String string : names) {
            result.append("<tns:filename>");
            result.append(string);
            result.append("</tns:filename>");
        }
        result.append("</tns:" + operation + "Response>");
        return result.toString();
    }

    public static void setIOFaultOnExchange(Exchange exchange, String ioMessage)
            throws JBIException {
        StringBuffer faultMessage = new StringBuffer();
        faultMessage.append("<tns:ioFault xmlns:tns='");
        faultMessage.append(FTPConstants.FTP_SERVICE_NS);
        faultMessage.append("'><tns:message>");
        faultMessage.append(ioMessage);
        faultMessage.append("</tns:message></tns:ioFault>");
        Fault fault = exchange.createFault();

        try {
            fault.setContent(UtilFactory.getSourceUtil().createSource(faultMessage.toString()));
            exchange.setFault(fault);
        } catch (PEtALSCDKException e) {
            throw new JBIException(e.getMessage());
        }
    }

    public static void setMissingElementFaultOnExchange(Exchange exchange, String missingElement)
            throws JBIException {
        StringBuffer faultMessage = new StringBuffer();
        faultMessage.append("<tns:missingElementFault xmlns:tns='");
        faultMessage.append(FTPConstants.FTP_SERVICE_NS);
        faultMessage.append("'><tns:element>");
        faultMessage.append(missingElement);
        faultMessage.append("</tns:element></tns:missingElementFault>");
        Fault fault = exchange.createFault();
        try {
            fault.setContent(UtilFactory.getSourceUtil().createSource(faultMessage.toString()));
        } catch (PEtALSCDKException e) {
            throw new JBIException(e.getMessage());
        }
        exchange.setFault(fault);
    }

}
